==> kubernetes-model-1.0.54-sources.jar: annotations/io/fabric8/kubernetes/api/model/LimitRangeSpecBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class LimitRangeSpecBuilder extends LimitRangeSpecFluentImpl<LimitRangeSpecBuilder> implements VisitableBuilder<LimitRangeSpec,LimitRangeSpecBuilder>{

    LimitRangeSpecFluent<?> fluent;
    Boolean validationEnabled;

    public LimitRangeSpecBuilder(){
            this(true);
    }
    public LimitRangeSpecBuilder(Boolean validationEnabled){
            this(new LimitRangeSpec(), validationEnabled);
    }
    public LimitRangeSpecBuilder(LimitRangeSpecFluent<?> fluent){
            this(fluent, true);
    }
    public LimitRangeSpecBuilder(LimitRangeSpecFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new LimitRangeSpec(), validationEnabled);
    }
    public LimitRangeSpecBuilder(LimitRangeSpecFluent<?> fluent,LimitRangeSpec instance){
            this(fluent, instance, true);
    }
    public LimitRangeSpecBuilder(LimitRangeSpecFluent<?> fluent,LimitRangeSpec instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withLimits(instance.getLimits()); 
            this.validationEnabled = validationEnabled; 
    }
    public LimitRangeSpecBuilder(LimitRangeSpec instance){
            this(instance,true);
    }
    public LimitRangeSpecBuilder(LimitRangeSpec instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withLimits(instance.getLimits()); 
            this.validationEnabled = validationEnabled; 
    }

    public LimitRangeSpec build(){
            LimitRangeSpec buildable = new LimitRangeSpec(fluent.getLimits());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            LimitRangeSpecBuilder that = (LimitRangeSpecBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-2.0.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/LimitRangeSpecBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class LimitRangeSpecBuilder extends LimitRangeSpecFluentImpl<LimitRangeSpecBuilder> implements VisitableBuilder<LimitRangeSpec,LimitRangeSpecBuilder>{

    LimitRangeSpecFluent<?> fluent;
    Boolean validationEnabled;

    public LimitRangeSpecBuilder(){
            this(true);
    }
    public LimitRangeSpecBuilder(Boolean validationEnabled){
            this(new LimitRangeSpec(), validationEnabled);
    }
    public LimitRangeSpecBuilder(LimitRangeSpecFluent<?> fluent){
            this(fluent, true);
    }
    public LimitRangeSpecBuilder(LimitRangeSpecFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new LimitRangeSpec(), validationEnabled);
    }
    public LimitRangeSpecBuilder(LimitRangeSpecFluent<?> fluent,LimitRangeSpec instance){
            this(fluent, instance, true);
    }
    public LimitRangeSpecBuilder(LimitRangeSpecFluent<?> fluent,LimitRangeSpec instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withLimits(instance.getLimits()); 
            this.validationEnabled = validationEnabled; 
    }
    public LimitRangeSpecBuilder(LimitRangeSpec instance){
            this(instance,true);
    }
    public LimitRangeSpecBuilder(LimitRangeSpec instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withLimits(instance.getLimits()); 
            this.validationEnabled = validationEnabled; 
    }

    public LimitRangeSpec build(){
            LimitRangeSpec buildable = new LimitRangeSpec(fluent.getLimits());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            LimitRangeSpecBuilder that = (LimitRangeSpecBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
